
From: Nishanth Aravamudan <nacc@us.ibm.com>

Use schedule_timeout_interruptible() instead of
set_current_state()/schedule_timeout() to reduce kernel size.  Also use
human-time to jiffies units conversion functions rather than direct HZ
division to avoid rounding issues.

(akpm: this patch relies on other stuff in -mm, please don't apply)

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/parport/ieee1284.c     |    7 +++----
 drivers/parport/ieee1284_ops.c |   10 ++++------
 drivers/parport/parport_pc.c   |    3 +--
 3 files changed, 8 insertions(+), 12 deletions(-)

diff -puN drivers/parport/ieee1284.c~parport-fix-up-schedule_timeout-usage drivers/parport/ieee1284.c
--- devel/drivers/parport/ieee1284.c~parport-fix-up-schedule_timeout-usage	2005-09-07 20:11:39.000000000 -0700
+++ devel-akpm/drivers/parport/ieee1284.c	2005-09-07 20:11:39.000000000 -0700
@@ -196,7 +196,7 @@ int parport_wait_peripheral(struct parpo
 		return 1;
 
 	/* 40ms of slow polling. */
-	deadline = jiffies + (HZ + 24) / 25;
+	deadline = jiffies + msecs_to_jiffies(40);
 	while (time_before (jiffies, deadline)) {
 		int ret;
 
@@ -205,7 +205,7 @@ int parport_wait_peripheral(struct parpo
 
 		/* Wait for 10ms (or until an interrupt occurs if
 		 * the handler is set) */
-		if ((ret = parport_wait_event (port, (HZ + 99) / 100)) < 0)
+		if ((ret = parport_wait_event (port, msecs_to_jiffies(10))) < 0)
 			return ret;
 
 		status = parport_read_status (port);
@@ -216,8 +216,7 @@ int parport_wait_peripheral(struct parpo
 			/* parport_wait_event didn't time out, but the
 			 * peripheral wasn't actually ready either.
 			 * Wait for another 10ms. */
-			__set_current_state (TASK_INTERRUPTIBLE);
-			schedule_timeout ((HZ+ 99) / 100);
+			schedule_timeout_interruptible(msecs_to_jiffies(10));
 		}
 	}
 
diff -puN drivers/parport/ieee1284_ops.c~parport-fix-up-schedule_timeout-usage drivers/parport/ieee1284_ops.c
--- devel/drivers/parport/ieee1284_ops.c~parport-fix-up-schedule_timeout-usage	2005-09-07 20:11:39.000000000 -0700
+++ devel-akpm/drivers/parport/ieee1284_ops.c	2005-09-07 20:11:39.000000000 -0700
@@ -60,7 +60,7 @@ size_t parport_ieee1284_write_compat (st
 	parport_data_forward (port);
 	while (count < len) {
 		unsigned long expire = jiffies + dev->timeout;
-		long wait = (HZ + 99) / 100;
+		long wait = msecs_to_jiffies(10);
 		unsigned char mask = (PARPORT_STATUS_ERROR
 				      | PARPORT_STATUS_BUSY);
 		unsigned char val = (PARPORT_STATUS_ERROR
@@ -97,8 +97,7 @@ size_t parport_ieee1284_write_compat (st
                            our interrupt handler called. */
 			if (count && no_irq) {
 				parport_release (dev);
-				__set_current_state (TASK_INTERRUPTIBLE);
-				schedule_timeout (wait);
+				schedule_timeout_interruptible(wait);
 				parport_claim_or_block (dev);
 			}
 			else
@@ -538,13 +537,12 @@ size_t parport_ieee1284_ecp_read_data (s
 			/* Yield the port for a while. */
 			if (count && dev->port->irq != PARPORT_IRQ_NONE) {
 				parport_release (dev);
-				__set_current_state (TASK_INTERRUPTIBLE);
-				schedule_timeout ((HZ + 24) / 25);
+				schedule_timeout_interruptible(msecs_to_jiffis(40));
 				parport_claim_or_block (dev);
 			}
 			else
 				/* We must have the device claimed here. */
-				parport_wait_event (port, (HZ + 24) / 25);
+				parport_wait_event (port, msecs_to_jiffies(40));
 
 			/* Is there a signal pending? */
 			if (signal_pending (current))
diff -puN drivers/parport/parport_pc.c~parport-fix-up-schedule_timeout-usage drivers/parport/parport_pc.c
--- devel/drivers/parport/parport_pc.c~parport-fix-up-schedule_timeout-usage	2005-09-07 20:11:39.000000000 -0700
+++ devel-akpm/drivers/parport/parport_pc.c	2005-09-07 20:11:39.000000000 -0700
@@ -173,8 +173,7 @@ static int change_mode(struct parport *p
 				if (time_after_eq (jiffies, expire))
 					/* The FIFO is stuck. */
 					return -EBUSY;
-				__set_current_state (TASK_INTERRUPTIBLE);
-				schedule_timeout ((HZ + 99) / 100);
+				schedule_timeout_interruptible(msecs_to_jiffies(10));
 				if (signal_pending (current))
 					break;
 			}
_
